#!/usr/bin/perl

use Quota;
require Schedule::At;
require 'account-admin-lib.pl';

#	Simple Email Function
#	($to, $from, $subject, $message)
sub sendEmail
{
	my ($to, $from, $subject, $message) = @_;
	my $sendmail = '/usr/lib/sendmail';
 	open(MAIL, "|$sendmail -oi -t");
 	print MAIL "From: $from\n";
 	print MAIL "To: $to\n";
 	print MAIL "Subject: $subject\n\n";
 	print MAIL "$message\n";
 	close(MAIL);
} 

ui_print_header(undef, $module_info{'desc'}, "");

# Create activity folder if not already created
$dir = 'quota_borrow_quota'; 
$quotafile = './' . $dir . '/' . $remote_user;
$scriptfile = './' . $dir . '/' . $remote_user . '.reset_script';
$shellscriptfile = $scriptfile . '.sh';
mkdir($dir);

$stdout = "";
$stderr = "";
$rstdout = \$stdout;
$rstderr = \$stderr;

print '<b>Doubling the account quota for one hour...</b>';

#Get current quota ------------------------------------------------------------------------
$dev = Quota::getqcarg('/');
$uid = getgrnam($remote_user);
($bc,$bs,$bh,$bt, $ic,$is,$ih,$it) = Quota::query($dev, $uid, 1);
print '<p><b>Current limits:</b><br>';
print 'Current usage: ' . $bc . '<br>';
#print 'Soft limit: ' . $bs . '<br>';
print 'Hard limit: ' . $bh . '<br>';
#print 'Block timelimit: ' . $bt . '<br>';
#print 'Inode current: ' . $ic . '<br>';
#print 'Inode soft: ' . $is . '<br>';
#print 'Inode hard: ' . $ih . '<br>';
#print 'Inode timelimit: ' . $it;

#Check that correct quota is set to prevent users from doubling the doubling... ------------------------------------------------------------------------
print '<p><b>Checking that double quota is not already active...</b><br>';
open (MYFILE, '<' . $quotafile);
$orgquota = <MYFILE>;
chomp($orgquota);
if($orgquota > 0) {
	print "Original account quota: " . $orgquota . '<br>';
} else {
	$orgquota = $bh;
}
close (MYFILE);

if($orgquota == "" || $orgquota >= $bh) {
	print "Double quota is not active. Continue with doubling the quota.";

	#Double the quota ------------------------------------------------------------------------
	$dev = Quota::getqcarg('/');
	$uid = getpwnam($remote_user);
	$gid = getgrnam($remote_user);
	$newbs = $bs * 2;
	$newbh = $bh * 2;
	$newis = $is;
	$newih = $ih;
	$tlo = 0; # Set time limits to not started
	print '<p><b>New limits:</b><br>';
	#print 'Soft limit: ' . $newbs . '<br>';
	print 'Hard limit: ' . $newbh . '<br>';
	Quota::setqlim($dev, $uid, $newbs,$newbh, $is,$ih, $tlo, 0); #Set for user
	Quota::setqlim($dev, $gid, $newbs,$newbh, $is,$ih, $tlo, 1); #Set for group
	
	# Send mail to support@nettools.se and inform about action
	sendEmail("support\@nettools.se", "webmin\@nettools.se", "Double quota for " . $remote_user , 
		"Double quota function started for user "  . $remote_user . "\n" .
		"Orginal account quota: " . $orgquota . "\n" .
		"New account quota: " . $newbh);

	# Print original quota to file in activity folder
	open (MYFILE, '>' . $quotafile);
	print MYFILE "$bh\n";
	close (MYFILE);

	#Create an at job that will remove the double quota in one hour ------------------------------------------------------------------------
	# Create script file
	open (MYFILE, '>' . $scriptfile);
	print MYFILE "#!/usr/bin/perl\n";
	print MYFILE "use Quota;\n";
	print MYFILE "Quota::setqlim('" . $dev . "', $uid, $orgquota, $orgquota, $is, $ih, $tlo, 0);\n";
	print MYFILE "Quota::setqlim('" . $dev . "', $gid, $orgquota, $orgquota, $is, $ih, $tlo, 1);\n";
	print MYFILE "unlink '" . $scriptfile . "';\n";
	print MYFILE "unlink '" . $shellscriptfile . "';\n";
	print MYFILE "unlink '" . $quotafile . "';\n";
	close (MYFILE);
	chmod(0755, $scriptfile);

	# Create shell script
	open (MYFILE, '>' . $shellscriptfile);
	print MYFILE "#!/bin/bash\n";
	print MYFILE "echo 'Double quota reset to original value for: " . $remote_user . "';\n";
	print MYFILE $scriptfile . ";\n";
	close (MYFILE);
	chmod(0755, $shellscriptfile);

	# Schedule
	$command = 'at -f ' . $shellscriptfile . ' now + 60 minutes';
	#print '<p>Running command: ' . $command . '<br>';
	execute_command($command, undef, $rstdout, $rstderr);
	#print '<br>Stdout: ' . $stdout . '<br>';
	#print '<br>Stderr: ' . $stderr . '<br>';
	$stderr = "";

} else {
	$errormessage = "Double quota already active.";
	print "$errormessage<br>";
	$stderr = $errormessage;
}



#END  ------------------------------------------------------------------------

#print '<br>Stdout: ' . $stdout . '<br>';
#print '<br>Stderr: ' . $stderr . '<br>';


if($stderr ne "") {
	print '<p><b>An error occured:</b><br>';
	print $stderr . '<br>';
	print 'Contact <a href="mailto:support@nettools.se">support@nettools.se</a> if this is incorrect.<br>';
} else {
	print '<p><b>Success:</b><br>';
	print 'The account quota is doubled for 1 hour.<br>';
}

ui_print_footer('', $text{'first_page'});
